/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlesystem_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlesystem_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlesystem_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QQuick3DParticleSystemE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSystem::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DParticleSystemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSystem",
        "QML.Element",
        "ParticleSystem3D",
        "QML.AddedInVersion",
        "1538",
        "runningChanged",
        "",
        "pausedChanged",
        "timeChanged",
        "startTimeChanged",
        "useRandomSeedChanged",
        "seedChanged",
        "loggingChanged",
        "loggingDataChanged",
        "setRunning",
        "running",
        "setPaused",
        "paused",
        "setStartTime",
        "startTime",
        "setTime",
        "time",
        "setUseRandomSeed",
        "randomize",
        "setSeed",
        "seed",
        "setLogging",
        "logging",
        "setEditorTime",
        "reset",
        "useRandomSeed",
        "loggingData",
        "QQuick3DParticleSystemLogging*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pausedChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startTimeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useRandomSeedChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seedChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loggingChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loggingDataChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRunning'
        QtMocHelpers::SlotData<void(bool)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setPaused'
        QtMocHelpers::SlotData<void(bool)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setStartTime'
        QtMocHelpers::SlotData<void(int)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setTime'
        QtMocHelpers::SlotData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setUseRandomSeed'
        QtMocHelpers::SlotData<void(bool)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setSeed'
        QtMocHelpers::SlotData<void(int)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setLogging'
        QtMocHelpers::SlotData<void(bool)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setEditorTime'
        QtMocHelpers::SlotData<void(int)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Method 'reset'
        QtMocHelpers::MethodData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'running'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'paused'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'startTime'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'time'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'useRandomSeed'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'seed'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'logging'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'loggingData'
        QtMocHelpers::PropertyData<QQuick3DParticleSystemLogging*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleSystem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSystem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleSystemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleSystemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DParticleSystemE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSystem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSystem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runningChanged(); break;
        case 1: _t->pausedChanged(); break;
        case 2: _t->timeChanged(); break;
        case 3: _t->startTimeChanged(); break;
        case 4: _t->useRandomSeedChanged(); break;
        case 5: _t->seedChanged(); break;
        case 6: _t->loggingChanged(); break;
        case 7: _t->loggingDataChanged(); break;
        case 8: _t->setRunning((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setPaused((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setStartTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setUseRandomSeed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setSeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setLogging((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setEditorTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::runningChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::pausedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::timeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::startTimeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::useRandomSeedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::seedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::loggingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystem::*)()>(_a, &QQuick3DParticleSystem::loggingDataChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleSystemLogging* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isRunning(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPaused(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->startTime(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->time(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->useRandomSeed(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->seed(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->logging(); break;
        case 7: *reinterpret_cast<QQuick3DParticleSystemLogging**>(_v) = _t->loggingData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRunning(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setPaused(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setStartTime(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setTime(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setUseRandomSeed(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSeed(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setLogging(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleSystem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSystem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleSystemE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DParticleSystem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleSystem::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleSystem::pausedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleSystem::timeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleSystem::startTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleSystem::useRandomSeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleSystem::seedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleSystem::loggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticleSystem::loggingDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSystemAnimation::qt_create_metaobjectdata<qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSystemAnimation"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DParticleSystemAnimation, qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSystemAnimation::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractAnimation::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSystemAnimation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSystemAnimation *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DParticleSystemAnimation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSystemAnimation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DParticleSystemAnimationE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractAnimation::qt_metacast(_clname);
}

int QQuick3DParticleSystemAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractAnimation::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSystemUpdate::qt_create_metaobjectdata<qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSystemUpdate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DParticleSystemUpdate, qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSystemUpdate::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractAnimation::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSystemUpdate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSystemUpdate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DParticleSystemUpdate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSystemUpdate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleSystemUpdateE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractAnimation::qt_metacast(_clname);
}

int QQuick3DParticleSystemUpdate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractAnimation::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
